ClientServer.ClientServerBuilder (py4j-java 0.10.9.4 API)
Date: 2022-03-16

py4j

## Class ClientServer.ClientServerBuilder

- java.lang.Object
- - py4j.ClientServer.ClientServerBuilder

- Enclosing class:
    ClientServer

      public static class ClientServer.ClientServerBuilder
      extends java.lang.Object

  Helper class to make it easier and self-documenting how a `ClientServer` is constructed.

- - ### Constructor Summary

    Constructors
    Constructor and Description
    `ClientServerBuilder()`
    `ClientServerBuilder(java.lang.Object entryPoint)`

  - ### Method Summary

    All Methods Instance Methods Concrete Methods
    Modifier and Type | Method and Description
    --- | ---
    `ClientServer.ClientServerBuilder` | `authToken(java.lang.String authToken)`
    `ClientServer.ClientServerBuilder` | `autoStartJavaServer(boolean autoStartJavaServer)`
    `ClientServer` | `build()`
    `ClientServer.ClientServerBuilder` | `connectTimeout(int connectTimeout)`
    `ClientServer.ClientServerBuilder` | `enableMemoryManagement(boolean enableMemoryManagement)`
    `ClientServer.ClientServerBuilder` | `entryPoint(java.lang.Object entryPoint)`
    `ClientServer.ClientServerBuilder` | `javaAddress(java.net.InetAddress javaAddress)`
    `ClientServer.ClientServerBuilder` | `javaPort(int javaPort)`
    `ClientServer.ClientServerBuilder` | `pythonAddress(java.net.InetAddress pythonAddress)`
    `ClientServer.ClientServerBuilder` | `pythonPort(int pythonPort)`
    `ClientServer.ClientServerBuilder` | `readTimeout(int readTimeout)`
    `ClientServer.ClientServerBuilder` | `serverSocketFactory(javax.net.ServerSocketFactory serverSocketFactory)`
    `ClientServer.ClientServerBuilder` | `socketFactory(javax.net.SocketFactory socketFactory)`

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

- - ### Constructor Detail

    - #### ClientServerBuilder

          public ClientServerBuilder()

    - #### ClientServerBuilder

          public ClientServerBuilder(java.lang.Object entryPoint)

  - ### Method Detail

    - #### build

          public ClientServer build()

    - #### javaPort

          public ClientServer.ClientServerBuilder javaPort(int javaPort)

    - #### javaAddress

          public ClientServer.ClientServerBuilder javaAddress(java.net.InetAddress javaAddress)

    - #### pythonPort

          public ClientServer.ClientServerBuilder pythonPort(int pythonPort)

    - #### pythonAddress

          public ClientServer.ClientServerBuilder pythonAddress(java.net.InetAddress pythonAddress)

    - #### connectTimeout

          public ClientServer.ClientServerBuilder connectTimeout(int connectTimeout)

    - #### readTimeout

          public ClientServer.ClientServerBuilder readTimeout(int readTimeout)

    - #### serverSocketFactory

          public ClientServer.ClientServerBuilder serverSocketFactory(javax.net.ServerSocketFactory serverSocketFactory)

    - #### socketFactory

          public ClientServer.ClientServerBuilder socketFactory(javax.net.SocketFactory socketFactory)

    - #### entryPoint

          public ClientServer.ClientServerBuilder entryPoint(java.lang.Object entryPoint)

    - #### autoStartJavaServer

          public ClientServer.ClientServerBuilder autoStartJavaServer(boolean autoStartJavaServer)

    - #### enableMemoryManagement

          public ClientServer.ClientServerBuilder enableMemoryManagement(boolean enableMemoryManagement)

    - #### authToken

          public ClientServer.ClientServerBuilder authToken(java.lang.String authToken)